@@ -1,26 +1,11 @@
 /*
-Copyright (C) 2001 - 2013 Evan Teran
-                          evan.teran@gmail.com
+    SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
+    SPDX-FileCopyrightText: 1996-2000 Bernd Johannes Wuebben <wuebben@kde.org>
 
-Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
-                          wuebben@kde.org
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KCALC_CORE_H_
-#define KCALC_CORE_H_
+#pragma once
 
 #include "knumber.h"
 #include "stats.h"
@@ -155,4 +140,3 @@ private:
     KNumber evalOperation(const KNumber &arg1, Operation operation, const KNumber &arg2);
 };
 
-#endif
