@@ -47,9 +47,7 @@ knumber_error::knumber_error()
 //------------------------------------------------------------------------------
 // Name:
 //------------------------------------------------------------------------------
-knumber_error::~knumber_error()
-{
-}
+knumber_error::~knumber_error() = default;
 
 //------------------------------------------------------------------------------
 // Name:
